# Everyware Starter Package
 
__Development requirements__
* [Docker environment](https://docs.docker.com/docker-for-mac/install/) - Will include nginx, MySQL, Redis and support for PHP 7.2
* [composer](#markdown-header-composer) - Dependency management for PHP
* [npm and Node.js](https://docs.npmjs.com/downloading-and-installing-node-js-and-npm) - Dependency management for Javascript

## Getting started

Regular Wordpress installation depends on Everyware and EveryBoard plugins.

To create the dev environment you should follow the steps and install the required software.
When all required software is installed it is time to setup your environment.

After that you will use **[Makefile](#markdown-header-makefile)** to start your project.

By running following command lets you install all necessary packages you need through `composer`, `npm` and will also download and prepare WordPress.

```bash
$ make init
```

To start up your local environment: 
```bash
$ make start
```

### Setting up .env-variables
When you have called the command `init` you will get a `.env` file in the root-folder.
You will also gain an example of this file for you to store in your project.
This will make sure your colleagues will get the file to set up when they start developing
From this file you can set up everything for your application.

### When "up and running"
Before we begin we have to check a few things.
Make a host redirect for your dev-domains in the system host-file.

```bash
127.0.0.1 everywarestarterkit.local
127.0.0.1 site.everywarestarterkit.local
```

> Mac: /etc/hosts  

Now log in to the Wordpress [wp-admin](https://everywarestarterkit.local/wp-admin):
1. Make sure the themes you'd like to use are network enabled in [Network Admin > Themes](https://everywarestarterkit.local/wp-admin/network/themes.php).
2. Now make sure the __site__ have the requiring [Plugins](https://site.everywarestarterkit.local/wp-admin/plugins.php) and [Theme](https://site.everywarestarterkit.local/wp-admin/themes.php).

### Everyware Structure theme
In the `wp-content/themes` directory you will now have access to a basic structure theme with the necessary files required to build
a WordPress theme for Everyware.  

_All done!_

## Documentation

### Makefile
We have a *Makefile* that can be used to handle docker commands and other utilities.
You can find the list och available commands in the file which is located in project root. 

Basic commands:
```bash
make init                       # Kick start the project and install all you need
make start                      # Starts all Docker containers for project
make stop                       # Stops all Docker containers for project
make restart                    # restarts all Docker containers for project
make pull                       # Download latest version of Docker containers
make redis-flush                # Flush redis
make luarocks                   # You only need to do this once on first start
make build-alt                  # Offers a way to run your project with an alternative composer config.
```

Wordpress commands:
```bash
make wp-install                   # Install WordPress
make wp-remove                    # Remove the part of WordPress that should not be versioned
make wp-update-salt               # Updates WordPress salt
```

Advanced commands:
```bash
$ make remove                       # Removes all containers except MySQL
$ make remove-mysql                 # Removes the MySQL container. You will lose all MySQL data so make sure you have a backup.
$ make mysql-dump                   # Dumps the content of your current MySQL container into an sql-file.
```

### Must use plugin
Everyware Starter Package have one must have plugin which is mandatory and will always be activated.    
It's located under `www/wp-content/mu-plugin/`.

### [Composer](https://getcomposer.org/)
The project php is handled by `composer`. You can find the configuration in `composer.json`.
Here you will find dependencies, code standard, namespaces etc.

Instructions on how to install composer can be found [here](https://getcomposer.org/doc/00-intro.md#installation-linux-unix-osx).  

When you have composer installed globally, run the following command from the `project-root`:

```bash
$ composer install
```

If you add dependencies i composer or if you want to update current dependencies use:

```bash
$ composer update
```

### Log files
Log files are automatically created in the project folder in the subfolder "log".

```bash
access.log              # (nginx access log)

error.log               # (nginx error log)

php-fpm-error.log       # (php-fpm error log)
```

Follow logs with

```bash
$ tail -f log/error.log
```

## CHANGELOG
Don't forget to update CHANGELOG.md with the changes made so it's easy for other developer 
to see what have happened.
