#!/bin/bash
SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" >/dev/null 2>&1 && pwd)"

set -e

# set current directory
cwd=$(pwd)

COMPOSER="${cwd}/composer.json"
COMPOSER_LOCK="${cwd}/composer.lock"
ALT_COMPOSER="${cwd}/alternative_composer.json"
STORED_COMPOSER="${cwd}/original_composer.json"
STORED_COMPOSER_LOCK="${cwd}/original_composer.lock"

# Replace versioned composer.json with alternative one
function switchComposer() {
  # First we store current composer files localy
  mv "${COMPOSER}" "${STORED_COMPOSER}"

  # Store any existing lock-file
  [[ ! -f "${COMPOSER_LOCK}" ]] || mv "${COMPOSER_LOCK}" "${STORED_COMPOSER_LOCK}"

  # Rename alternative composer
  mv "${ALT_COMPOSER}" "${COMPOSER}"
  echo "Switch composer files...OK!"
}

function restoreComposer() {
  # First we restore alternative composer.json
  mv "${COMPOSER}" "${ALT_COMPOSER}"

  # Restore original composer file from local storage
  mv "${STORED_COMPOSER}" "${COMPOSER}"

  if [[ -f "${STORED_COMPOSER_LOCK}" ]]; then

    # Remove alternative composer.lock
    [[ ! -f "${COMPOSER_LOCK}" ]] || rm "${COMPOSER_LOCK}"

    mv "${STORED_COMPOSER_LOCK}" "${COMPOSER_LOCK}"
  fi
  echo "Restore composer files...OK!"
}

# Check for alternative composer file
if [ ! -f "${ALT_COMPOSER}" ]; then
  echo "Could not find an alternative composer file!"
  echo ""
  read -p "Do you want to create one (y/N)? " answer
  case ${answer:0:1} in
      y|Y )
      echo "Creating: ${ALT_COMPOSER}"
      cp "${COMPOSER}" "${ALT_COMPOSER}"
      exit;;
    * )
      echo "${GREEN}${BOLD}> Make sure to create "${ALT_COMPOSER}"!${RESET}"
      exit;;
  esac
fi

switchComposer
echo "Run composer with alternative configuration..."
composer "$@"
restoreComposer
